context("canvasXpress Web Charts - Correlation")


test_that("cXcorrelation1", {
    check_ui_test(cXcorrelation1())
})

test_that("cXcorrelation2", {
    check_ui_test(cXcorrelation2())
})

test_that("cXcorrelation3", {
    check_ui_test(cXcorrelation3())
})

test_that("cXcorrelation4", {
    check_ui_test(cXcorrelation4())
})
